# XY

XY commands are used to plot X-Y data and store its display attributes and to write X-Y data to an ASCII file.

## Create XY Objects in Session

```{eval-rst}
.. autoclass:: abaqus.XY.XYSession.XYSession
    :members:
    :show-inheritance:

    .. autoclasstoc::
```

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.XY
        :recursive:
        :exclude: XYSession

    .. placeholder for empty members
```
